# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseInstallmentInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_costs': 'str',
        'additional_costs_percentage': 'str',
        'amount': 'str',
        'amount_funded': 'str',
        'amount_requested_percentage': 'str',
        'annual_financing_cost': 'str',
        'annual_interest_rate': 'str',
        'expenses': 'str',
        'expenses_percentage': 'str',
        'fees': 'str',
        'fees_percentage': 'str',
        'frequency': 'str',
        'insurance': 'str',
        'insurance_percentage': 'str',
        'invoice_data': 'str',
        'monthly_interest_rate': 'str',
        'plan_type': 'str',
        'sequence': 'int',
        'taxes': 'str',
        'taxes_percentage': 'str',
        'total_amount': 'str',
        'total_count': 'int',
        'minimum_total_count': 'str',
        'maximum_total_count': 'str',
        'first_installment_amount': 'str',
        'first_installment_date': 'str'
    }

    attribute_map = {
        'additional_costs': 'additionalCosts',
        'additional_costs_percentage': 'additionalCostsPercentage',
        'amount': 'amount',
        'amount_funded': 'amountFunded',
        'amount_requested_percentage': 'amountRequestedPercentage',
        'annual_financing_cost': 'annualFinancingCost',
        'annual_interest_rate': 'annualInterestRate',
        'expenses': 'expenses',
        'expenses_percentage': 'expensesPercentage',
        'fees': 'fees',
        'fees_percentage': 'feesPercentage',
        'frequency': 'frequency',
        'insurance': 'insurance',
        'insurance_percentage': 'insurancePercentage',
        'invoice_data': 'invoiceData',
        'monthly_interest_rate': 'monthlyInterestRate',
        'plan_type': 'planType',
        'sequence': 'sequence',
        'taxes': 'taxes',
        'taxes_percentage': 'taxesPercentage',
        'total_amount': 'totalAmount',
        'total_count': 'totalCount',
        'minimum_total_count': 'minimumTotalCount',
        'maximum_total_count': 'maximumTotalCount',
        'first_installment_amount': 'firstInstallmentAmount',
        'first_installment_date': 'firstInstallmentDate'
    }

    def __init__(self, additional_costs=None, additional_costs_percentage=None, amount=None, amount_funded=None, amount_requested_percentage=None, annual_financing_cost=None, annual_interest_rate=None, expenses=None, expenses_percentage=None, fees=None, fees_percentage=None, frequency=None, insurance=None, insurance_percentage=None, invoice_data=None, monthly_interest_rate=None, plan_type=None, sequence=None, taxes=None, taxes_percentage=None, total_amount=None, total_count=None, minimum_total_count=None, maximum_total_count=None, first_installment_amount=None, first_installment_date=None):
        """
        PtsV2PaymentsPost201ResponseInstallmentInformation - a model defined in Swagger
        """

        self._additional_costs = None
        self._additional_costs_percentage = None
        self._amount = None
        self._amount_funded = None
        self._amount_requested_percentage = None
        self._annual_financing_cost = None
        self._annual_interest_rate = None
        self._expenses = None
        self._expenses_percentage = None
        self._fees = None
        self._fees_percentage = None
        self._frequency = None
        self._insurance = None
        self._insurance_percentage = None
        self._invoice_data = None
        self._monthly_interest_rate = None
        self._plan_type = None
        self._sequence = None
        self._taxes = None
        self._taxes_percentage = None
        self._total_amount = None
        self._total_count = None
        self._minimum_total_count = None
        self._maximum_total_count = None
        self._first_installment_amount = None
        self._first_installment_date = None

        if additional_costs is not None:
          self.additional_costs = additional_costs
        if additional_costs_percentage is not None:
          self.additional_costs_percentage = additional_costs_percentage
        if amount is not None:
          self.amount = amount
        if amount_funded is not None:
          self.amount_funded = amount_funded
        if amount_requested_percentage is not None:
          self.amount_requested_percentage = amount_requested_percentage
        if annual_financing_cost is not None:
          self.annual_financing_cost = annual_financing_cost
        if annual_interest_rate is not None:
          self.annual_interest_rate = annual_interest_rate
        if expenses is not None:
          self.expenses = expenses
        if expenses_percentage is not None:
          self.expenses_percentage = expenses_percentage
        if fees is not None:
          self.fees = fees
        if fees_percentage is not None:
          self.fees_percentage = fees_percentage
        if frequency is not None:
          self.frequency = frequency
        if insurance is not None:
          self.insurance = insurance
        if insurance_percentage is not None:
          self.insurance_percentage = insurance_percentage
        if invoice_data is not None:
          self.invoice_data = invoice_data
        if monthly_interest_rate is not None:
          self.monthly_interest_rate = monthly_interest_rate
        if plan_type is not None:
          self.plan_type = plan_type
        if sequence is not None:
          self.sequence = sequence
        if taxes is not None:
          self.taxes = taxes
        if taxes_percentage is not None:
          self.taxes_percentage = taxes_percentage
        if total_amount is not None:
          self.total_amount = total_amount
        if total_count is not None:
          self.total_count = total_count
        if minimum_total_count is not None:
          self.minimum_total_count = minimum_total_count
        if maximum_total_count is not None:
          self.maximum_total_count = maximum_total_count
        if first_installment_amount is not None:
          self.first_installment_amount = first_installment_amount
        if first_installment_date is not None:
          self.first_installment_date = first_installment_date

    @property
    def additional_costs(self):
        """
        Gets the additional_costs of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Additional costs charged by the issuer to fund the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 128-139 - Field: Total Other Costs 

        :return: The additional_costs of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._additional_costs

    @additional_costs.setter
    def additional_costs(self, additional_costs):
        """
        Sets the additional_costs of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Additional costs charged by the issuer to fund the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 128-139 - Field: Total Other Costs 

        :param additional_costs: The additional_costs of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if additional_costs is not None and len(additional_costs) > 12:
            raise ValueError("Invalid value for `additional_costs`, length must be less than or equal to `12`")

        self._additional_costs = additional_costs

    @property
    def additional_costs_percentage(self):
        """
        Gets the additional_costs_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Additional costs divided by the amount funded.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 140-143 - Field: Percent of Total Other Costs 

        :return: The additional_costs_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._additional_costs_percentage

    @additional_costs_percentage.setter
    def additional_costs_percentage(self, additional_costs_percentage):
        """
        Sets the additional_costs_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Additional costs divided by the amount funded.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 140-143 - Field: Percent of Total Other Costs 

        :param additional_costs_percentage: The additional_costs_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if additional_costs_percentage is not None and len(additional_costs_percentage) > 4:
            raise ValueError("Invalid value for `additional_costs_percentage`, length must be less than or equal to `4`")

        self._additional_costs_percentage = additional_costs_percentage

    @property
    def amount(self):
        """
        Gets the amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Amount for the current installment payment.  This field is supported only for CyberSource through VisaNet.  For details, see `installment_amount` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Amount for the current installment payment.  This field is supported only for CyberSource through VisaNet.  For details, see `installment_amount` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param amount: The amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if amount is not None and len(amount) > 12:
            raise ValueError("Invalid value for `amount`, length must be less than or equal to `12`")

        self._amount = amount

    @property
    def amount_funded(self):
        """
        Gets the amount_funded of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Amount funded.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 48-59 - Field: Total Amount Funded 

        :return: The amount_funded of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._amount_funded

    @amount_funded.setter
    def amount_funded(self, amount_funded):
        """
        Sets the amount_funded of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Amount funded.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 48-59 - Field: Total Amount Funded 

        :param amount_funded: The amount_funded of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if amount_funded is not None and len(amount_funded) > 12:
            raise ValueError("Invalid value for `amount_funded`, length must be less than or equal to `12`")

        self._amount_funded = amount_funded

    @property
    def amount_requested_percentage(self):
        """
        Gets the amount_requested_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Amount requested divided by the amount funded.  For example: - A value of 90.0 specifies 90%. - A value of 93.7 specifies 93.7%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 60-63 - Field: Percent of Amount Requested 

        :return: The amount_requested_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._amount_requested_percentage

    @amount_requested_percentage.setter
    def amount_requested_percentage(self, amount_requested_percentage):
        """
        Sets the amount_requested_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Amount requested divided by the amount funded.  For example: - A value of 90.0 specifies 90%. - A value of 93.7 specifies 93.7%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 60-63 - Field: Percent of Amount Requested 

        :param amount_requested_percentage: The amount_requested_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if amount_requested_percentage is not None and len(amount_requested_percentage) > 4:
            raise ValueError("Invalid value for `amount_requested_percentage`, length must be less than or equal to `4`")

        self._amount_requested_percentage = amount_requested_percentage

    @property
    def annual_financing_cost(self):
        """
        Gets the annual_financing_cost of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Annual cost of financing the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 158-164 - Field: Annual Total Cost of Financing 

        :return: The annual_financing_cost of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._annual_financing_cost

    @annual_financing_cost.setter
    def annual_financing_cost(self, annual_financing_cost):
        """
        Sets the annual_financing_cost of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Annual cost of financing the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 158-164 - Field: Annual Total Cost of Financing 

        :param annual_financing_cost: The annual_financing_cost of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if annual_financing_cost is not None and len(annual_financing_cost) > 7:
            raise ValueError("Invalid value for `annual_financing_cost`, length must be less than or equal to `7`")

        self._annual_financing_cost = annual_financing_cost

    @property
    def annual_interest_rate(self):
        """
        Gets the annual_interest_rate of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Annual interest rate.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 151-157 - Field: Annual Interest Rate 

        :return: The annual_interest_rate of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._annual_interest_rate

    @annual_interest_rate.setter
    def annual_interest_rate(self, annual_interest_rate):
        """
        Sets the annual_interest_rate of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Annual interest rate.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 151-157 - Field: Annual Interest Rate 

        :param annual_interest_rate: The annual_interest_rate of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if annual_interest_rate is not None and len(annual_interest_rate) > 7:
            raise ValueError("Invalid value for `annual_interest_rate`, length must be less than or equal to `7`")

        self._annual_interest_rate = annual_interest_rate

    @property
    def expenses(self):
        """
        Gets the expenses of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Expenses charged by the issuer to fund the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 64-75 - Field: Total Expenses 

        :return: The expenses of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._expenses

    @expenses.setter
    def expenses(self, expenses):
        """
        Sets the expenses of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Expenses charged by the issuer to fund the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 64-75 - Field: Total Expenses 

        :param expenses: The expenses of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if expenses is not None and len(expenses) > 12:
            raise ValueError("Invalid value for `expenses`, length must be less than or equal to `12`")

        self._expenses = expenses

    @property
    def expenses_percentage(self):
        """
        Gets the expenses_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Expenses divided by the amount funded.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 76-79 - Field: Percent of Total Expenses 

        :return: The expenses_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._expenses_percentage

    @expenses_percentage.setter
    def expenses_percentage(self, expenses_percentage):
        """
        Sets the expenses_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Expenses divided by the amount funded.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 76-79 - Field: Percent of Total Expenses 

        :param expenses_percentage: The expenses_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if expenses_percentage is not None and len(expenses_percentage) > 4:
            raise ValueError("Invalid value for `expenses_percentage`, length must be less than or equal to `4`")

        self._expenses_percentage = expenses_percentage

    @property
    def fees(self):
        """
        Gets the fees of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Fees charged by the issuer to fund the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 80-91 - Field: Total Fees 

        :return: The fees of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._fees

    @fees.setter
    def fees(self, fees):
        """
        Sets the fees of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Fees charged by the issuer to fund the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 80-91 - Field: Total Fees 

        :param fees: The fees of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if fees is not None and len(fees) > 12:
            raise ValueError("Invalid value for `fees`, length must be less than or equal to `12`")

        self._fees = fees

    @property
    def fees_percentage(self):
        """
        Gets the fees_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Fees divided by the amount funded.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on CyberSource through VisaNet.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 92-95 - Field: Percent of Total Fees 

        :return: The fees_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._fees_percentage

    @fees_percentage.setter
    def fees_percentage(self, fees_percentage):
        """
        Sets the fees_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Fees divided by the amount funded.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on CyberSource through VisaNet.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 92-95 - Field: Percent of Total Fees 

        :param fees_percentage: The fees_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if fees_percentage is not None and len(fees_percentage) > 4:
            raise ValueError("Invalid value for `fees_percentage`, length must be less than or equal to `4`")

        self._fees_percentage = fees_percentage

    @property
    def frequency(self):
        """
        Gets the frequency of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Frequency of the installment payments. When you do not include this field in a request for a Crediario installment payment, CyberSource sends a space character to the processor.  For details, see `installment_frequency` field description in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for CyberSource through VisaNet. Possible values: - `B`: Biweekly - `M`: Monthly - `W`: Weekly  For Crediario installment payments, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCR9 - Position: 41 - Field: Installment Frequency  For details, see \"Installment Payments\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The frequency of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """
        Sets the frequency of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Frequency of the installment payments. When you do not include this field in a request for a Crediario installment payment, CyberSource sends a space character to the processor.  For details, see `installment_frequency` field description in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for CyberSource through VisaNet. Possible values: - `B`: Biweekly - `M`: Monthly - `W`: Weekly  For Crediario installment payments, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCR9 - Position: 41 - Field: Installment Frequency  For details, see \"Installment Payments\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param frequency: The frequency of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if frequency is not None and len(frequency) > 1:
            raise ValueError("Invalid value for `frequency`, length must be less than or equal to `1`")

        self._frequency = frequency

    @property
    def insurance(self):
        """
        Gets the insurance of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Insurance charged by the issuer to fund the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 112-123 - Field: Total Insurance 

        :return: The insurance of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._insurance

    @insurance.setter
    def insurance(self, insurance):
        """
        Sets the insurance of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Insurance charged by the issuer to fund the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 112-123 - Field: Total Insurance 

        :param insurance: The insurance of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if insurance is not None and len(insurance) > 12:
            raise ValueError("Invalid value for `insurance`, length must be less than or equal to `12`")

        self._insurance = insurance

    @property
    def insurance_percentage(self):
        """
        Gets the insurance_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Insurance costs divided by the amount funded.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 124-127 - Field: Percent Of Total Insurance 

        :return: The insurance_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._insurance_percentage

    @insurance_percentage.setter
    def insurance_percentage(self, insurance_percentage):
        """
        Sets the insurance_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Insurance costs divided by the amount funded.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 124-127 - Field: Percent Of Total Insurance 

        :param insurance_percentage: The insurance_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if insurance_percentage is not None and len(insurance_percentage) > 4:
            raise ValueError("Invalid value for `insurance_percentage`, length must be less than or equal to `4`")

        self._insurance_percentage = insurance_percentage

    @property
    def invoice_data(self):
        """
        Gets the invoice_data of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Invoice information that you want to provide to the issuer. This value is similar to a tracking number and is the same for all installment payments for one purchase.  This field is supported only for installment payments with Mastercard on CyberSource through VisaNet in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  The value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP07 TCR4 - Position: 51-70 - Field: Purchase Identification 

        :return: The invoice_data of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._invoice_data

    @invoice_data.setter
    def invoice_data(self, invoice_data):
        """
        Sets the invoice_data of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Invoice information that you want to provide to the issuer. This value is similar to a tracking number and is the same for all installment payments for one purchase.  This field is supported only for installment payments with Mastercard on CyberSource through VisaNet in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  The value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP07 TCR4 - Position: 51-70 - Field: Purchase Identification 

        :param invoice_data: The invoice_data of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if invoice_data is not None and len(invoice_data) > 20:
            raise ValueError("Invalid value for `invoice_data`, length must be less than or equal to `20`")

        self._invoice_data = invoice_data

    @property
    def monthly_interest_rate(self):
        """
        Gets the monthly_interest_rate of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Monthly interest rate.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 144-150 - Field: Monthly Interest Rate 

        :return: The monthly_interest_rate of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._monthly_interest_rate

    @monthly_interest_rate.setter
    def monthly_interest_rate(self, monthly_interest_rate):
        """
        Sets the monthly_interest_rate of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Monthly interest rate.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 144-150 - Field: Monthly Interest Rate 

        :param monthly_interest_rate: The monthly_interest_rate of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if monthly_interest_rate is not None and len(monthly_interest_rate) > 7:
            raise ValueError("Invalid value for `monthly_interest_rate`, length must be less than or equal to `7`")

        self._monthly_interest_rate = monthly_interest_rate

    @property
    def plan_type(self):
        """
        Gets the plan_type of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        #### American Express Direct, Cielo, and CyberSource Latin American Processing Flag that indicates the type of funding for the installment plan associated with the payment.  Possible values: - `1`: Merchant-funded installment plan - `2`: Issuer-funded installment plan If you do not include this field in the request, CyberSource uses the value in your CyberSource account.  To change the value in your CyberSource account, contact CyberSource Customer Service. For details, see `installment_plan_type` field description in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet and American Express Defined code that indicates the type of installment plan for this transaction.  Contact American Express for: - Information about the kinds of installment plans that American Express provides - Values for this field  For installment payments with American Express in Brazil, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP07 TCR3 - Position: 5-6 - Field: Plan Type  * The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies.  #### CyberSource through VisaNet with Visa or Mastercard Flag indicating the type of funding for the installment plan associated with the payment. Possible values: - 1 or 01: Merchant-funded installment plan - 2 or 02: Issuer-funded installment plan - 43: Crediario installment plan—only with Visa in Brazil For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  For installment payments with Visa in Brazil, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP07 TCR1 - Position: 5-6 - Field: Installment Type  For all other kinds of installment payments, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCR5 - Position: 39-40 - Field: Installment Plan Type (Issuer or Merchant) 

        :return: The plan_type of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._plan_type

    @plan_type.setter
    def plan_type(self, plan_type):
        """
        Sets the plan_type of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        #### American Express Direct, Cielo, and CyberSource Latin American Processing Flag that indicates the type of funding for the installment plan associated with the payment.  Possible values: - `1`: Merchant-funded installment plan - `2`: Issuer-funded installment plan If you do not include this field in the request, CyberSource uses the value in your CyberSource account.  To change the value in your CyberSource account, contact CyberSource Customer Service. For details, see `installment_plan_type` field description in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet and American Express Defined code that indicates the type of installment plan for this transaction.  Contact American Express for: - Information about the kinds of installment plans that American Express provides - Values for this field  For installment payments with American Express in Brazil, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP07 TCR3 - Position: 5-6 - Field: Plan Type  * The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies.  #### CyberSource through VisaNet with Visa or Mastercard Flag indicating the type of funding for the installment plan associated with the payment. Possible values: - 1 or 01: Merchant-funded installment plan - 2 or 02: Issuer-funded installment plan - 43: Crediario installment plan—only with Visa in Brazil For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  For installment payments with Visa in Brazil, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP07 TCR1 - Position: 5-6 - Field: Installment Type  For all other kinds of installment payments, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCR5 - Position: 39-40 - Field: Installment Plan Type (Issuer or Merchant) 

        :param plan_type: The plan_type of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if plan_type is not None and len(plan_type) > 1:
            raise ValueError("Invalid value for `plan_type`, length must be less than or equal to `1`")

        self._plan_type = plan_type

    @property
    def sequence(self):
        """
        Gets the sequence of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Installment number when making payments in installments. Used along with `totalCount` to track which payment is being processed.  For example, the second of 5 payments would be passed to CyberSource as `sequence` = 2 and `totalCount` = 5.  For details, see \"Installment Payments\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### Chase Paymentech Solutions and FDC Compass This field is optional because this value is required in the merchant descriptors. For details, see \"Chase Paymentech Solutions Merchant Descriptors\" and \"FDC Compass Merchant Descriptors\" in the [Merchant Descriptors Using the SCMP API] (https://apps.cybersource.com/library/documentation/dev_guides/Merchant_Descriptors_SCMP_API/html/)  #### CyberSource through VisaNet When you do not include this field in a request for a Crediario installment payment, CyberSource sends a value of 0 to the processor.  For Crediario installment payments, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP01 TCR9 - Position: 38-40 - Field: Installment Payment Number  * The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies. 

        :return: The sequence of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: int
        """
        return self._sequence

    @sequence.setter
    def sequence(self, sequence):
        """
        Sets the sequence of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Installment number when making payments in installments. Used along with `totalCount` to track which payment is being processed.  For example, the second of 5 payments would be passed to CyberSource as `sequence` = 2 and `totalCount` = 5.  For details, see \"Installment Payments\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### Chase Paymentech Solutions and FDC Compass This field is optional because this value is required in the merchant descriptors. For details, see \"Chase Paymentech Solutions Merchant Descriptors\" and \"FDC Compass Merchant Descriptors\" in the [Merchant Descriptors Using the SCMP API] (https://apps.cybersource.com/library/documentation/dev_guides/Merchant_Descriptors_SCMP_API/html/)  #### CyberSource through VisaNet When you do not include this field in a request for a Crediario installment payment, CyberSource sends a value of 0 to the processor.  For Crediario installment payments, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP01 TCR9 - Position: 38-40 - Field: Installment Payment Number  * The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies. 

        :param sequence: The sequence of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: int
        """
        if sequence is not None and sequence > 99:
            raise ValueError("Invalid value for `sequence`, must be a value less than or equal to `99`")

        self._sequence = sequence

    @property
    def taxes(self):
        """
        Gets the taxes of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Taxes collected by the issuer to fund the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 96-107 - Field: Total Taxes 

        :return: The taxes of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._taxes

    @taxes.setter
    def taxes(self, taxes):
        """
        Sets the taxes of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Taxes collected by the issuer to fund the installment payments.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 96-107 - Field: Total Taxes 

        :param taxes: The taxes of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if taxes is not None and len(taxes) > 12:
            raise ValueError("Invalid value for `taxes`, length must be less than or equal to `12`")

        self._taxes = taxes

    @property
    def taxes_percentage(self):
        """
        Gets the taxes_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Taxes divided by the amount funded.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 108-111 - Field: Percent of Total Taxes 

        :return: The taxes_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._taxes_percentage

    @taxes_percentage.setter
    def taxes_percentage(self, taxes_percentage):
        """
        Sets the taxes_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Taxes divided by the amount funded.  For example: - A value of 1.0 specifies 1%. - A value of 4.0 specifies 4%.  This field is included in the authorization reply for the Crediario eligibility request when the issuer approves the cardholder's request for Crediario installment payments in Brazil.  For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on **CyberSource through VisaNet**.  The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR9 - Position: 108-111 - Field: Percent of Total Taxes 

        :param taxes_percentage: The taxes_percentage of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if taxes_percentage is not None and len(taxes_percentage) > 4:
            raise ValueError("Invalid value for `taxes_percentage`, length must be less than or equal to `4`")

        self._taxes_percentage = taxes_percentage

    @property
    def total_amount(self):
        """
        Gets the total_amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Total amount of the loan that is being paid in installments. This field is supported only for CyberSource through VisaNet.  For details, see \"Installment Payments\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The total_amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """
        Sets the total_amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Total amount of the loan that is being paid in installments. This field is supported only for CyberSource through VisaNet.  For details, see \"Installment Payments\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param total_amount: The total_amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if total_amount is not None and len(total_amount) > 12:
            raise ValueError("Invalid value for `total_amount`, length must be less than or equal to `12`")

        self._total_amount = total_amount

    @property
    def total_count(self):
        """
        Gets the total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Total number of installments when making payments in installments.  For details, see \"Installment Payments\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### Chase Paymentech Solutions and FDC Compass This field is optional because this value is required in the merchant descriptors.  For details, see \"Chase Paymentech Solutions Merchant Descriptors\" and \"FDC Compass Merchant Descriptors\" in the [Merchant Descriptors Using the SCMP API.] (https://apps.cybersource.com/library/documentation/dev_guides/Merchant_Descriptors_SCMP_API/html/)  #### American Express Direct, Cielo, and Comercio Latino This value is the total number of installments you approved.  #### CyberSource Latin American Processing in Brazil This value is the total number of installments that you approved. The default is 1.  #### All Other Processors This value is used along with _sequence_ to track which payment is being processed.  For example, the second of 5 payments would be passed to CyberSource as _sequence_ = 2 and _totalCount_ = 5.  #### CyberSource through VisaNet For Crediario installment payments, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP01 TCR9 - Position: 23-25 - Field: Number of Installments  For installment payments with American Express in Brazil, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP07 TCR3 - Position: 7-8 - Field: Number of Installments  For installment payments with Visa in Brazil, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP07 TCR1 - Position: 7-8 - Field: Number of Installments  For all other kinds of installment payments, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP01 TCR5 - Position: 20-22 - Field: Installment Total Count  **Note** The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies. 

        :return: The total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """
        Sets the total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Total number of installments when making payments in installments.  For details, see \"Installment Payments\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### Chase Paymentech Solutions and FDC Compass This field is optional because this value is required in the merchant descriptors.  For details, see \"Chase Paymentech Solutions Merchant Descriptors\" and \"FDC Compass Merchant Descriptors\" in the [Merchant Descriptors Using the SCMP API.] (https://apps.cybersource.com/library/documentation/dev_guides/Merchant_Descriptors_SCMP_API/html/)  #### American Express Direct, Cielo, and Comercio Latino This value is the total number of installments you approved.  #### CyberSource Latin American Processing in Brazil This value is the total number of installments that you approved. The default is 1.  #### All Other Processors This value is used along with _sequence_ to track which payment is being processed.  For example, the second of 5 payments would be passed to CyberSource as _sequence_ = 2 and _totalCount_ = 5.  #### CyberSource through VisaNet For Crediario installment payments, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP01 TCR9 - Position: 23-25 - Field: Number of Installments  For installment payments with American Express in Brazil, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP07 TCR3 - Position: 7-8 - Field: Number of Installments  For installment payments with Visa in Brazil, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP07 TCR1 - Position: 7-8 - Field: Number of Installments  For all other kinds of installment payments, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP01 TCR5 - Position: 20-22 - Field: Installment Total Count  **Note** The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies. 

        :param total_count: The total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: int
        """
        if total_count is not None and total_count > 99:
            raise ValueError("Invalid value for `total_count`, must be a value less than or equal to `99`")

        self._total_count = total_count

    @property
    def minimum_total_count(self):
        """
        Gets the minimum_total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        \"Minimum number of installments offered by the issuer for this purchase. The issuer provides this value when the first installment payment is successful. This field is supported for installment payments with Mastercard on CyberSource through VisaNet in all countries except Brazil, Croatia, Georgia, and Greece. The value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCR5 - Position: 75-76 - Field: Mastercard Minimum Number Of Installments 

        :return: The minimum_total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._minimum_total_count

    @minimum_total_count.setter
    def minimum_total_count(self, minimum_total_count):
        """
        Sets the minimum_total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        \"Minimum number of installments offered by the issuer for this purchase. The issuer provides this value when the first installment payment is successful. This field is supported for installment payments with Mastercard on CyberSource through VisaNet in all countries except Brazil, Croatia, Georgia, and Greece. The value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCR5 - Position: 75-76 - Field: Mastercard Minimum Number Of Installments 

        :param minimum_total_count: The minimum_total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """

        self._minimum_total_count = minimum_total_count

    @property
    def maximum_total_count(self):
        """
        Gets the maximum_total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Maximum number of installments offered by the issuer for this purchase. The issuer provides this value when the first installment payment is successful. This field is supported for installment payments with Mastercard on CyberSource through VisaNet in all countries except Brazil, Croatia, Georgia, and Greece. The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR5 - Position: 77-78 - Field: Mastercard Maximum Number Of Installments 

        :return: The maximum_total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._maximum_total_count

    @maximum_total_count.setter
    def maximum_total_count(self, maximum_total_count):
        """
        Sets the maximum_total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Maximum number of installments offered by the issuer for this purchase. The issuer provides this value when the first installment payment is successful. This field is supported for installment payments with Mastercard on CyberSource through VisaNet in all countries except Brazil, Croatia, Georgia, and Greece. The value for this field corresponds to the following data in the TC 33 capture file1: - Record: CP01 TCR5 - Position: 77-78 - Field: Mastercard Maximum Number Of Installments 

        :param maximum_total_count: The maximum_total_count of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """

        self._maximum_total_count = maximum_total_count

    @property
    def first_installment_amount(self):
        """
        Gets the first_installment_amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Amount of the first installment payment. The issuer provides this value when the first installment payment is successful. This field is supported for Mastercard installment payments on CyberSource through VisaNet in all countries except Brazil,Croatia, Georgia, and Greece. The value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCR5 - Position: 23-34 - Field: Amount of Each Installment 

        :return: The first_installment_amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._first_installment_amount

    @first_installment_amount.setter
    def first_installment_amount(self, first_installment_amount):
        """
        Sets the first_installment_amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Amount of the first installment payment. The issuer provides this value when the first installment payment is successful. This field is supported for Mastercard installment payments on CyberSource through VisaNet in all countries except Brazil,Croatia, Georgia, and Greece. The value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCR5 - Position: 23-34 - Field: Amount of Each Installment 

        :param first_installment_amount: The first_installment_amount of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if first_installment_amount is not None and len(first_installment_amount) > 13:
            raise ValueError("Invalid value for `first_installment_amount`, length must be less than or equal to `13`")

        self._first_installment_amount = first_installment_amount

    @property
    def first_installment_date(self):
        """
        Gets the first_installment_date of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Date of the first installment payment. Format: YYMMDD. When you do not include this field, CyberSource sends a string of six zeros (000000) to the processor. For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on CyberSource through VisaNet.  The value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCR9 - Position: 42-47 - Field: Date of First Installment 

        :return: The first_installment_date of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :rtype: str
        """
        return self._first_installment_date

    @first_installment_date.setter
    def first_installment_date(self, first_installment_date):
        """
        Sets the first_installment_date of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        Date of the first installment payment. Format: YYMMDD. When you do not include this field, CyberSource sends a string of six zeros (000000) to the processor. For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  This field is supported only for Crediario installment payments in Brazil on CyberSource through VisaNet.  The value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCR9 - Position: 42-47 - Field: Date of First Installment 

        :param first_installment_date: The first_installment_date of this PtsV2PaymentsPost201ResponseInstallmentInformation.
        :type: str
        """
        if first_installment_date is not None and len(first_installment_date) > 6:
            raise ValueError("Invalid value for `first_installment_date`, length must be less than or equal to `6`")

        self._first_installment_date = first_installment_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseInstallmentInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.apis.customer_shipping_address_api import CustomerShippingAddressApi


class TestCustomerShippingAddressApi(unittest.TestCase):
    """ CustomerShippingAddressApi unit test stubs """

    def setUp(self):
        self.api = CyberSource.apis.customer_shipping_address_api.CustomerShippingAddressApi()

    def tearDown(self):
        pass

    def test_delete_customer_shipping_address(self):
        """
        Test case for delete_customer_shipping_address

        Delete a Customer Shipping Address
        """
        pass

    def test_get_customer_shipping_address(self):
        """
        Test case for get_customer_shipping_address

        Retrieve a Customer Shipping Address
        """
        pass

    def test_get_customer_shipping_addresses_list(self):
        """
        Test case for get_customer_shipping_addresses_list

        List Shipping Addresses for a Customer
        """
        pass

    def test_patch_customers_shipping_address(self):
        """
        Test case for patch_customers_shipping_address

        Update a Customer Shipping Address
        """
        pass

    def test_post_customer_shipping_address(self):
        """
        Test case for post_customer_shipping_address

        Create a Customer Shipping Address
        """
        pass


if __name__ == '__main__':
    unittest.main()



import hashlib
import base64


class DigestAndPayload:
    def __init__(self):
        self.__blue_print = None
        self.__payload_msg_body = None
        self.json_path = None

    def string_digest_generation(self, json_path_data):
        # This method returns digest value which is SHA-256 hash of the payload which is BASE-64 Encoded
        self.json_path = json_path_data
        message_body = self.json_path
        hashobj = hashlib.sha256()
        hashobj.update(message_body.encode('utf-8'))
        hash_data = hashobj.digest()
        encoded_data = base64.b64encode(hash_data)
        blue_print = encoded_data

        return blue_print

    # This method reads the data from request.json and forms a string of data acquired from the request.json file
    # noinspection PyMethodMayBeStatic
    def string_payload_generation(self, path):
        message_list = []
        message_body = ""
        requestfile = open(path)

        for i in requestfile:
            message_list.append(i)
            message_body = "".join(message_list)
        requestfile.close()

        return message_body



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'total_amount': 'str',
        'currency': 'str',
        'balance_amount': 'str',
        'discount_amount': 'str',
        'discount_percent': 'float',
        'sub_amount': 'float',
        'minimum_partial_amount': 'float',
        'tax_details': 'Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails',
        'freight': 'Invoicingv2invoicesOrderInformationAmountDetailsFreight'
    }

    attribute_map = {
        'total_amount': 'totalAmount',
        'currency': 'currency',
        'balance_amount': 'balanceAmount',
        'discount_amount': 'discountAmount',
        'discount_percent': 'discountPercent',
        'sub_amount': 'subAmount',
        'minimum_partial_amount': 'minimumPartialAmount',
        'tax_details': 'taxDetails',
        'freight': 'freight'
    }

    def __init__(self, total_amount=None, currency=None, balance_amount=None, discount_amount=None, discount_percent=None, sub_amount=None, minimum_partial_amount=None, tax_details=None, freight=None):
        """
        InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails - a model defined in Swagger
        """

        self._total_amount = None
        self._currency = None
        self._balance_amount = None
        self._discount_amount = None
        self._discount_percent = None
        self._sub_amount = None
        self._minimum_partial_amount = None
        self._tax_details = None
        self._freight = None

        if total_amount is not None:
          self.total_amount = total_amount
        if currency is not None:
          self.currency = currency
        if balance_amount is not None:
          self.balance_amount = balance_amount
        if discount_amount is not None:
          self.discount_amount = discount_amount
        if discount_percent is not None:
          self.discount_percent = discount_percent
        if sub_amount is not None:
          self.sub_amount = sub_amount
        if minimum_partial_amount is not None:
          self.minimum_partial_amount = minimum_partial_amount
        if tax_details is not None:
          self.tax_details = tax_details
        if freight is not None:
          self.freight = freight

    @property
    def total_amount(self):
        """
        Gets the total_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        Grand total for the order. This value cannot be negative. You can include a decimal point (.), but no other special characters. CyberSource truncates the amount to the correct number of decimal places.  **Note** For CTV, FDCCompass, Paymentech processors, the maximum length for this field is 12.  **Important** Some processors have specific requirements and limitations, such as maximum amounts and maximum field lengths. For details, see: - \"Authorization Information for Specific Processors\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/). - \"Capture Information for Specific Processors\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/). - \"Credit Information for Specific Processors\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/).  If your processor supports zero amount authorizations, you can set this field to 0 for the authorization to check if the card is lost or stolen. For details, see \"Zero Amount Authorizations,\" \"Credit Information for Specific Processors\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### Card Present Required to include either this field or `orderInformation.lineItems[].unitPrice` for the order.  #### Invoicing Required for creating a new invoice.  #### PIN Debit Amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount.  Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.  #### GPX This field is optional for reversing an authorization or credit; however, for all other processors, these fields are required.  #### DCC with a Third-Party Provider Set this field to the converted amount that was returned by the DCC provider. You must include either this field or the 1st line item in the order and the specific line-order amount in your request. For details, see `grand_total_amount` field description in [Dynamic Currency Conversion For First Data Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/DCC_FirstData_SCMP/DCC_FirstData_SCMP_API.pdf).  #### FDMS South If you accept IDR or CLP currencies, see the entry for FDMS South in \"Authorization Information for Specific Processors\" of the [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### DCC for First Data Not used. 

        :return: The total_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :rtype: str
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """
        Sets the total_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        Grand total for the order. This value cannot be negative. You can include a decimal point (.), but no other special characters. CyberSource truncates the amount to the correct number of decimal places.  **Note** For CTV, FDCCompass, Paymentech processors, the maximum length for this field is 12.  **Important** Some processors have specific requirements and limitations, such as maximum amounts and maximum field lengths. For details, see: - \"Authorization Information for Specific Processors\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/). - \"Capture Information for Specific Processors\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/). - \"Credit Information for Specific Processors\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/).  If your processor supports zero amount authorizations, you can set this field to 0 for the authorization to check if the card is lost or stolen. For details, see \"Zero Amount Authorizations,\" \"Credit Information for Specific Processors\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### Card Present Required to include either this field or `orderInformation.lineItems[].unitPrice` for the order.  #### Invoicing Required for creating a new invoice.  #### PIN Debit Amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount.  Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.  #### GPX This field is optional for reversing an authorization or credit; however, for all other processors, these fields are required.  #### DCC with a Third-Party Provider Set this field to the converted amount that was returned by the DCC provider. You must include either this field or the 1st line item in the order and the specific line-order amount in your request. For details, see `grand_total_amount` field description in [Dynamic Currency Conversion For First Data Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/DCC_FirstData_SCMP/DCC_FirstData_SCMP_API.pdf).  #### FDMS South If you accept IDR or CLP currencies, see the entry for FDMS South in \"Authorization Information for Specific Processors\" of the [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### DCC for First Data Not used. 

        :param total_amount: The total_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :type: str
        """
        if total_amount is not None and len(total_amount) > 19:
            raise ValueError("Invalid value for `total_amount`, length must be less than or equal to `19`")

        self._total_amount = total_amount

    @property
    def currency(self):
        """
        Gets the currency of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        Currency used for the order. Use the three-character [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)  #### Used by **Authorization** Required field.  **Authorization Reversal** For an authorization reversal (`reversalInformation`) or a capture (`processingOptions.capture` is set to `true`), you must use the same currency that you used in your payment authorization request.  #### PIN Debit Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf). Returned by PIN debit purchase.  For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf).  Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.  #### GPX This field is optional for reversing an authorization or credit.  #### DCC for First Data Your local currency. For details, see the `currency` field description in [Dynamic Currency Conversion For First Data Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/DCC_FirstData_SCMP/DCC_FirstData_SCMP_API.pdf).  #### Tax Calculation Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency. 

        :return: The currency of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        Currency used for the order. Use the three-character [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)  #### Used by **Authorization** Required field.  **Authorization Reversal** For an authorization reversal (`reversalInformation`) or a capture (`processingOptions.capture` is set to `true`), you must use the same currency that you used in your payment authorization request.  #### PIN Debit Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf). Returned by PIN debit purchase.  For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf).  Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.  #### GPX This field is optional for reversing an authorization or credit.  #### DCC for First Data Your local currency. For details, see the `currency` field description in [Dynamic Currency Conversion For First Data Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/DCC_FirstData_SCMP/DCC_FirstData_SCMP_API.pdf).  #### Tax Calculation Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency. 

        :param currency: The currency of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :type: str
        """
        if currency is not None and len(currency) > 3:
            raise ValueError("Invalid value for `currency`, length must be less than or equal to `3`")

        self._currency = currency

    @property
    def balance_amount(self):
        """
        Gets the balance_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        Remaining balance on the account.  Returned by authorization service.  #### PIN debit Remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :return: The balance_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :rtype: str
        """
        return self._balance_amount

    @balance_amount.setter
    def balance_amount(self, balance_amount):
        """
        Sets the balance_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        Remaining balance on the account.  Returned by authorization service.  #### PIN debit Remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :param balance_amount: The balance_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :type: str
        """
        if balance_amount is not None and len(balance_amount) > 12:
            raise ValueError("Invalid value for `balance_amount`, length must be less than or equal to `12`")

        self._balance_amount = balance_amount

    @property
    def discount_amount(self):
        """
        Gets the discount_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        Total discount amount applied to the order. 

        :return: The discount_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :rtype: str
        """
        return self._discount_amount

    @discount_amount.setter
    def discount_amount(self, discount_amount):
        """
        Sets the discount_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        Total discount amount applied to the order. 

        :param discount_amount: The discount_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :type: str
        """
        if discount_amount is not None and len(discount_amount) > 15:
            raise ValueError("Invalid value for `discount_amount`, length must be less than or equal to `15`")

        self._discount_amount = discount_amount

    @property
    def discount_percent(self):
        """
        Gets the discount_percent of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        The total discount percentage applied to the invoice.

        :return: The discount_percent of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :rtype: float
        """
        return self._discount_percent

    @discount_percent.setter
    def discount_percent(self, discount_percent):
        """
        Sets the discount_percent of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        The total discount percentage applied to the invoice.

        :param discount_percent: The discount_percent of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :type: float
        """

        self._discount_percent = discount_percent

    @property
    def sub_amount(self):
        """
        Gets the sub_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        Sub-amount of the invoice.

        :return: The sub_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :rtype: float
        """
        return self._sub_amount

    @sub_amount.setter
    def sub_amount(self, sub_amount):
        """
        Sets the sub_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        Sub-amount of the invoice.

        :param sub_amount: The sub_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :type: float
        """

        self._sub_amount = sub_amount

    @property
    def minimum_partial_amount(self):
        """
        Gets the minimum_partial_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        The minimum partial amount required to pay the invoice.

        :return: The minimum_partial_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :rtype: float
        """
        return self._minimum_partial_amount

    @minimum_partial_amount.setter
    def minimum_partial_amount(self, minimum_partial_amount):
        """
        Sets the minimum_partial_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        The minimum partial amount required to pay the invoice.

        :param minimum_partial_amount: The minimum_partial_amount of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :type: float
        """

        self._minimum_partial_amount = minimum_partial_amount

    @property
    def tax_details(self):
        """
        Gets the tax_details of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.

        :return: The tax_details of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :rtype: Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails
        """
        return self._tax_details

    @tax_details.setter
    def tax_details(self, tax_details):
        """
        Sets the tax_details of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.

        :param tax_details: The tax_details of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :type: Invoicingv2invoicesOrderInformationAmountDetailsTaxDetails
        """

        self._tax_details = tax_details

    @property
    def freight(self):
        """
        Gets the freight of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.

        :return: The freight of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :rtype: Invoicingv2invoicesOrderInformationAmountDetailsFreight
        """
        return self._freight

    @freight.setter
    def freight(self, freight):
        """
        Sets the freight of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.

        :param freight: The freight of this InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails.
        :type: Invoicingv2invoicesOrderInformationAmountDetailsFreight
        """

        self._freight = freight

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, InvoicingV2InvoicesPost201ResponseOrderInformationAmountDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2payoutsClientReferenceInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'str',
        'application_name': 'str',
        'application_version': 'str',
        'application_user': 'str'
    }

    attribute_map = {
        'code': 'code',
        'application_name': 'applicationName',
        'application_version': 'applicationVersion',
        'application_user': 'applicationUser'
    }

    def __init__(self, code=None, application_name=None, application_version=None, application_user=None):
        """
        Ptsv2payoutsClientReferenceInformation - a model defined in Swagger
        """

        self._code = None
        self._application_name = None
        self._application_version = None
        self._application_user = None

        if code is not None:
          self.code = code
        if application_name is not None:
          self.application_name = application_name
        if application_version is not None:
          self.application_version = application_version
        if application_user is not None:
          self.application_user = application_user

    @property
    def code(self):
        """
        Gets the code of this Ptsv2payoutsClientReferenceInformation.
        Merchant-generated order reference or tracking number. It is recommended that you send a unique value for each transaction so that you can perform meaningful searches for the transaction.  #### Used by **Authorization** Required field.  #### PIN Debit Requests for PIN debit reversals need to use the same merchant reference number that was used in the transaction that is being reversed.  Required field for all PIN Debit requests (purchase, credit, and reversal).  #### FDC Nashville Global Certain circumstances can cause the processor to truncate this value to 15 or 17 characters for Level II and Level III processing, which can cause a discrepancy between the value you submit and the value included in some processor reports. 

        :return: The code of this Ptsv2payoutsClientReferenceInformation.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this Ptsv2payoutsClientReferenceInformation.
        Merchant-generated order reference or tracking number. It is recommended that you send a unique value for each transaction so that you can perform meaningful searches for the transaction.  #### Used by **Authorization** Required field.  #### PIN Debit Requests for PIN debit reversals need to use the same merchant reference number that was used in the transaction that is being reversed.  Required field for all PIN Debit requests (purchase, credit, and reversal).  #### FDC Nashville Global Certain circumstances can cause the processor to truncate this value to 15 or 17 characters for Level II and Level III processing, which can cause a discrepancy between the value you submit and the value included in some processor reports. 

        :param code: The code of this Ptsv2payoutsClientReferenceInformation.
        :type: str
        """
        if code is not None and len(code) > 50:
            raise ValueError("Invalid value for `code`, length must be less than or equal to `50`")

        self._code = code

    @property
    def application_name(self):
        """
        Gets the application_name of this Ptsv2payoutsClientReferenceInformation.
        The name of the Connection Method client (such as Virtual Terminal or SOAP Toolkit API) that the merchant uses to send a transaction request to CyberSource. 

        :return: The application_name of this Ptsv2payoutsClientReferenceInformation.
        :rtype: str
        """
        return self._application_name

    @application_name.setter
    def application_name(self, application_name):
        """
        Sets the application_name of this Ptsv2payoutsClientReferenceInformation.
        The name of the Connection Method client (such as Virtual Terminal or SOAP Toolkit API) that the merchant uses to send a transaction request to CyberSource. 

        :param application_name: The application_name of this Ptsv2payoutsClientReferenceInformation.
        :type: str
        """

        self._application_name = application_name

    @property
    def application_version(self):
        """
        Gets the application_version of this Ptsv2payoutsClientReferenceInformation.
        Version of the CyberSource application or integration used for a transaction. 

        :return: The application_version of this Ptsv2payoutsClientReferenceInformation.
        :rtype: str
        """
        return self._application_version

    @application_version.setter
    def application_version(self, application_version):
        """
        Sets the application_version of this Ptsv2payoutsClientReferenceInformation.
        Version of the CyberSource application or integration used for a transaction. 

        :param application_version: The application_version of this Ptsv2payoutsClientReferenceInformation.
        :type: str
        """

        self._application_version = application_version

    @property
    def application_user(self):
        """
        Gets the application_user of this Ptsv2payoutsClientReferenceInformation.
        The entity that is responsible for running the transaction and submitting the processing request to CyberSource. This could be a person, a system, or a connection method. 

        :return: The application_user of this Ptsv2payoutsClientReferenceInformation.
        :rtype: str
        """
        return self._application_user

    @application_user.setter
    def application_user(self, application_user):
        """
        Sets the application_user of this Ptsv2payoutsClientReferenceInformation.
        The entity that is responsible for running the transaction and submitting the processing request to CyberSource. This could be a person, a system, or a connection method. 

        :param application_user: The application_user of this Ptsv2payoutsClientReferenceInformation.
        :type: str
        """

        self._application_user = application_user

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2payoutsClientReferenceInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from authenticationsdk.util.GlobalLabelParameters import *
from wsgiref.handlers import format_date_time
from datetime import datetime
from time import mktime
import ast
import json
import authenticationsdk.util.ExceptionAuth
import os
import authenticationsdk.logger.Log


class MerchantConfiguration:

    def __init__(self):
        self.merchant_keyid = None
        self.merchant_secretkey = None
        self.merchant_id = None
        self.host_name = None
        self.url = None
        self.request_host = None
        self.request_type_method = None
        self.request_target = None
        self.authentication_type = None
        self.key_file_path = None
        self.run_environment = None
        self.key_alias = None
        self.key_password = None
        self.response_code = None
        self.response_message = None
        self.v_c_correlation_id = None
        self.enable_log = None
        self.maximum_size = None
        self.log_directory = None
        self.log_file_name = None
        self.proxy_address = None
        self.proxy_port = None
        self.key_file_name = None
        self.request_json_path_data = None
        self.log = None
        self.solution_id = None

    def set_merchant_keyid(self, value):
        if not (value.get('merchant_keyid') is None):
            self.merchant_keyid = value['merchant_keyid']

    def set_merchant_secretkey(self, value):
        if not (value.get('merchant_secretkey') is None):
            self.merchant_secretkey = value['merchant_secretkey']

    def set_key_file_path(self, value):
        if not (value.get('keys_directory') is None):
            self.key_file_path = value['keys_directory']

    def set_log_file_name(self, value):
        if not (value.get('log_file_name') is None or value.get('log_file_name') == ""):
            self.log_file_name = value['log_file_name']
        else:
            self.log_file_name = GlobalLabelParameters.LOG_FILE_NAME_DEFAULT

    def set_key_alias(self, value):
        if not (value.get('key_alias') is None):
            self.key_alias = value['key_alias']

    def set_key_password(self, value):
        if not (value.get('key_password') is None):
            self.key_password = value['key_password']

    def set_authentication_type(self, value):
        if not (value.get('authentication_type') is None):
            self.authentication_type = value['authentication_type']

    def set_merchant_id(self, value):
        if not (value.get('merchantid') is None):
            self.merchant_id = value['merchantid']

    def set_enable_log(self, value):

        if not (value.get('enable_log') == "" or value.get('enable_log') is None):
            self.enable_log = value['enable_log']
        else:
            self.enable_log = GlobalLabelParameters.DEFAULT_ENABLE_LOG

    def set_maximum_size(self, value):

        if not (value.get('log_maximum_size') == "" or value.get('log_maximum_size') is None):
            self.maximum_size = value['log_maximum_size']
        else:
            self.maximum_size = GlobalLabelParameters.DEFAULT_MAXIMUM_SIZE  # 10 MB = 10485760 bytes

    def set_log_directory(self, value):

        if not (value.get('log_directory') == "" or value.get('log_directory') is None):
            if os.path.exists(value['log_directory']) or os.path.isdir(value['log_directory']):
                self.log_directory = value['log_directory']
            else:
                self.log_directory = GlobalLabelParameters.DEFAULT_LOG_DIRECTORY
        else:
            self.log_directory = GlobalLabelParameters.DEFAULT_LOG_DIRECTORY

    def set_run_environment(self, value):
        if not (value.get('run_environment') is None):
            self.run_environment = value['run_environment']

    # setting up hostname based on the run environment value
    def set_request_host(self, value):
        if not (value.get("run_environment") is None):
            if self.run_environment.lower() == GlobalLabelParameters.SANBOX_RUN_ENVIRONMENT.lower():
                self.request_host = GlobalLabelParameters.SANBOX_URL
            elif self.run_environment.lower() == GlobalLabelParameters.PRODUCTION_RUN_ENVIRONMENT.lower():
                self.request_host = GlobalLabelParameters.PRODUCTION_URL
            elif self.run_environment.lower() == GlobalLabelParameters.BOA_SANDBOX_RUN_ENVIRONMENT.lower():
                self.request_host = GlobalLabelParameters.BOA_SANDBOX_URL
            elif self.run_environment.lower() == GlobalLabelParameters.BOA_PRODUCTION_RUN_ENVIRONMENT.lower():
                self.request_host = GlobalLabelParameters.BOA_PRODUCTION_URL
            elif self.run_environment.lower() == GlobalLabelParameters.IDC_SANDBOX_RUN_ENVIRONMENT.lower():
                self.request_host = GlobalLabelParameters.IDC_SANDBOX_URL
            elif self.run_environment.lower() == GlobalLabelParameters.IDC_PRODUCTION_RUN_ENVIRONMENT.lower():
                self.request_host = GlobalLabelParameters.IDC_PRODUCTION_URL
            else:
                self.request_host = self.run_environment

    def set_proxy_address(self, value):
        if not (value.get('proxy_address') is None):
            self.proxy_address = value['proxy_address']

    def set_proxy_port(self, value):
        if not (value.get("proxy_port") is None):
            self.proxy_port = value['proxy_port']

    def set_key_file_name(self, value):
        if not (value.get('key_file_name') is None):
            self.key_file_name = value['key_file_name']

    def set_solution_id(self, value):
        if not (value.get('solution_id') is None):
            self.solution_id = value['solution_id']

    # This method sets the Merchant Configuration Variables to its respective values after reading from cybs.properties
    def set_merchantconfig(self, val):

        self.set_key_password(val)
        self.set_key_alias(val)
        self.set_key_file_path(val)
        self.set_key_file_name(val)
        self.set_merchant_keyid(val)
        self.set_merchant_secretkey(val)
        self.set_run_environment(val)
        self.set_merchant_id(val)
        self.set_authentication_type(val)
        self.set_enable_log(val)
        self.set_maximum_size(val)
        self.set_log_directory(val)
        self.set_request_host(val)
        self.set_log_file_name(val)
        self.set_proxy_address(val)
        self.set_proxy_port(val)
        self.set_solution_id(val)

    # Returns the time in format as defined by RFC7231
    def get_time(self):
        now = datetime.now()
        stamp = mktime(now.timetuple())

        return format_date_time(stamp)

    # This validates the Merchant details
    def validate_merchant_details(self, details, mconfig):
        # verify Mandatory Properties
        logger = authenticationsdk.logger.Log.setup_logger(mconfig)
        mconfig.log = logger
        if self.enable_log is True:
            logger.info("START> ======================================= ")
        if self.merchant_id is None or self.merchant_id == "":
            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
                                                                               GlobalLabelParameters.MERCHANTID_REQ,
                                                                               mconfig)

        if self.authentication_type is None or self.authentication_type == "":
            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
                                                                               GlobalLabelParameters.AUTHENTICATION_REQ,
                                                                               mconfig)

        if self.run_environment is None or self.run_environment == "":
            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
                                                                               GlobalLabelParameters.RUN_ENVIRONMENT_EMPTY,
                                                                               mconfig)

        # Fallback for missing values
        if details.get('enable_log') is None or details.get('enable_log') == "":
            authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
                                                                         GlobalLabelParameters.ENABLE_LOG_DEFAULT_MESSAGE,
                                                                         mconfig)

        if details.get('log_maximum_size') is None or details.get('log_maximum_size') == "":
            authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
                                                                         GlobalLabelParameters.LOG_MAXIMUM_SIZE_DEFAULT_MESSAGE,
                                                                         mconfig)
        if details.get('log_file_name') is None or details.get('log_file_name') == "":
            authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
                                                                         GlobalLabelParameters.DEFAULT_LOG_FILE_NAME,
                                                                         mconfig)

        if details.get('log_directory') is None or details.get('log_directory') == "":
            authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
                                                                         GlobalLabelParameters.LOG_DIRECTORY_DEFAULT_MESSAGE,
                                                                         mconfig)
        elif not (os.path.exists(details.get('log_directory')) or os.path.isdir(details.get('log_directory'))):

            authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
                                                                         GlobalLabelParameters.LOG_DIRECTORY_INCORRECT_MESSAGE,
                                                                         mconfig)

        # This process ensures that merchant_keyid and merchant_secretkey are mandatory in case of HTTP
        # And displays warning if key alias ,key_password,key_filepath,keyfilename are not present when
        # the method is JWT

        if type(self.authentication_type) == str:
            if self.authentication_type.lower() == GlobalLabelParameters.HTTP.lower():
                if self.merchant_keyid is None or self.merchant_keyid == "":
                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
                                                                                       GlobalLabelParameters.MERCHANT_KEY_ID_REQ,
                                                                                       mconfig)

                if self.merchant_secretkey is None or self.merchant_secretkey == "":
                    authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
                                                                                       GlobalLabelParameters.MERCHANT_SECRET_KEY_REQ,
                                                                                       mconfig)

            elif self.authentication_type.lower() == GlobalLabelParameters.JWT.lower():
                if self.key_alias is None or self.key_alias == "":
                    self.key_alias = self.merchant_id
                    authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
                                                                                 GlobalLabelParameters.KEY_ALIAS_NULL_EMPTY,
                                                                                 mconfig)
                if not (self.key_alias == self.merchant_id):
                    self.key_alias = self.merchant_id
                    authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
                                                                                 GlobalLabelParameters.INVALID_KEY_ALIAS,
                                                                                 mconfig)

                if self.key_password is None or self.key_password == "":
                    self.key_password = self.merchant_id
                    authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
                                                                                 GlobalLabelParameters.KEY_PASSWORD_EMPTY,
                                                                                 mconfig)

                if self.key_file_path is None or self.key_file_path == "":
                    self.key_file_path = GlobalLabelParameters.DEFAULT_KEY_FILE_PATH
                    authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
                                                                                 GlobalLabelParameters.KEY_DIRECTORY_EMPTY + self.key_file_path,
                                                                                 mconfig)

                if self.key_file_name is None or self.key_file_name == "":
                    self.key_file_name = self.merchant_id

                    authenticationsdk.util.ExceptionAuth.validate_default_values(logger,
                                                                                 GlobalLabelParameters.KEY_FILE_EMPTY,
                                                                                 mconfig)
        else:
            authenticationsdk.util.ExceptionAuth.validate_merchant_details_log(logger,
                                                                               GlobalLabelParameters.AUTH_ERROR,
                                                                               mconfig)

        log_items = GlobalLabelParameters.HIDE_MERCHANT_CONFIG_PROPS
        # This displays the logic for logging all cybs.json values
        if self.enable_log is True:
            for key, value in list(details.items()):
                if key in log_items:
                    del details[key]

                for keys, values in list(details.items()):
                    details[keys] = str(values)

            logger.info("Mconfig >      " + str(ast.literal_eval(json.dumps(details))))



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.apis.verification_api import VerificationApi


class TestVerificationApi(unittest.TestCase):
    """ VerificationApi unit test stubs """

    def setUp(self):
        self.api = CyberSource.apis.verification_api.VerificationApi()

    def tearDown(self):
        pass

    def test_validate_export_compliance(self):
        """
        Test case for validate_export_compliance

        Validate export compliance
        """
        pass

    def test_verify_customer_address(self):
        """
        Test case for verify_customer_address

        Verify customer address
        """
        pass


if __name__ == '__main__':
    unittest.main()



import unittest
from authenticationsdk.core.MerchantConfiguration import *
from authenticationsdk.core.Authorization import *
import authenticationsdk.logger.Log
import authenticationsdk.util.PropertiesUtil
import logging
from authenticationsdk.core.MockData import *


class TestBasicFunction(unittest.TestCase):
    def setUp(self):
        self.func = Authorization()
        self.merchant_config =MerchantConfiguration()
        self.date = self.merchant_config.get_time()
        logging.disable(logging.CRITICAL)

    def tearDown(self):
        logging.disable(logging.NOTSET)

    # This method checks the HTTP_Get token  Generation Unit Testing
    def test_token_for_get_http(self):
        self.merchant_config.set_merchantconfig(MockData.HTTP_VALUES)
        self.merchant_config.request_type_method = "GET"
        self.get_id = "5246387105766473203529"
        self.merchant_config.request_target = "/pts/v2/payments/" + self.get_id

        self.logger = authenticationsdk.logger.Log.setup_logger(self.merchant_config)

        self.assertIsNotNone(self.func.get_token(self.merchant_config, self.date, self.logger))

    # This method checks the HTTP_Get token  Generation when enable_log,Log_Maximum_Size,Log_Directory  is None/Empty
    def test_get_http_enable_log(self):
        self.merchant_config.set_merchantconfig(MockData.HTTP_DEFAULT_VALUES)

        self.merchant_config.request_type_method = "GET"
        self.get_id = "5246387105766473203529"
        self.merchant_config.request_target = "/pts/v2/payments/" + self.get_id
        self.logger = authenticationsdk.logger.Log.setup_logger(self.merchant_config)
        self.merchant_config.validate_merchant_details(MockData.HTTP_DEFAULT_VALUES, self.merchant_config)

        self.assertIsNotNone(self.func.get_token(self.merchant_config, self.date, self.logger))

    # This method checks the HTTP_Get token  Generation when the run_environment="CyberSource.Environment.PRODUCTION"
    def test_get_jwt_production_url(self):
        self.merchant_config.set_merchantconfig(MockData.JWT_VALUES_FOR_PRODUCTION)

        self.merchant_config.request_type_method = "GET"
        self.get_id = "5246387105766473203529"
        self.merchant_config.request_target = "/pts/v2/payments/" + self.get_id
        self.logger = authenticationsdk.logger.Log.setup_logger(self.merchant_config)
        self.merchant_config.validate_merchant_details(MockData.JWT_VALUES_FOR_PRODUCTION,
                                                       self.merchant_config)

        self.assertIsNotNone(self.func.get_token(self.merchant_config, self.date, self.logger))

    # This method checks the HTTP_Post token  Generation Unit Testing
    def test_token_for_post_http(self):
        self.merchant_config.set_merchantconfig(MockData.HTTP_VALUES)
        self.merchant_config.request_type_method = "POST"
        self.merchant_config.request_target = "/pts/v2/payments"

        self.logger = authenticationsdk.logger.Log.setup_logger(self.merchant_config)
        
        self.merchant_config.request_json_path_data = json.dumps(MockData.REQUEST_DATA)

        self.assertIsNotNone(self.func.get_token(self.merchant_config, self.date, self.logger))

    # This method checks the HTTP_Put token  Generation Unit Testing
    def test_token_for_put_http(self):
        self.merchant_config.set_merchantconfig(MockData.HTTP_VALUES)
        self.merchant_config.request_type_method = "PUT"

        self.merchant_config.request_target = "/reporting/v2/reportSubscriptions/TRRReport?organizationId=testrest"

        self.logger = authenticationsdk.logger.Log.setup_logger(self.merchant_config)
        
        self.merchant_config.request_json_path_data = json.dumps(MockData.TRR_DATA)

        self.assertIsNotNone(self.func.get_token(self.merchant_config, self.date, self.logger))

    # This method checks the HTTP_Delete token  Generation Unit Testing
    def test_token_for_delete_http(self):
        self.merchant_config.set_merchantconfig(MockData.HTTP_VALUES)
        self.merchant_config.request_type_method = "DELETE"

        self.merchant_config.request_target = "/reporting/v2/reportSubscriptions/TRRReport?organizationId=testrest/5246387105766473203529"

        self.logger = authenticationsdk.logger.Log.setup_logger(self.merchant_config)

        self.assertIsNotNone(self.func.get_token(self.merchant_config, self.date, self.logger))

    # This method checks the JWT_Get token  Generation Unit Testing
    def test_token_for_get_jwt(self):
        self.merchant_config.set_merchantconfig(MockData.JWT_VALUES)
        self.merchant_config.request_type_method = "GET"
        self.get_id = "5246387105766473203529"
        self.merchant_config.request_target = "/pts/v2/payments/" + self.get_id

        self.logger = authenticationsdk.logger.Log.setup_logger(self.merchant_config)

        self.assertIsNotNone(self.func.get_token(self.merchant_config, self.date, self.logger))

    # This method checks the JWT_Post token  Generation Unit Testing
    def test_token_for_post_jwt(self):
        self.merchant_config.set_merchantconfig(MockData.JWT_VALUES)
        self.merchant_config.request_type_method = "POST"
        self.merchant_config.request_target = "/pts/v2/payments/5246387105766473203529"
        
        self.logger = authenticationsdk.logger.Log.setup_logger(self.merchant_config)

        self.merchant_config.request_json_path_data = json.dumps(MockData.REQUEST_DATA)

        self.assertIsNotNone(self.func.get_token(self.merchant_config, self.date, self.logger))

    # This method checks the JWT_Put token  Generation Unit Testing
    def test_token_for_put_jwt(self):
        self.merchant_config.set_merchantconfig(MockData.JWT_VALUES)
        self.merchant_config.request_type_method = "PUT"

        self.merchant_config.request_target = "/reporting/v2/reportSubscriptions/TRRReport?organizationId=testrest"

        self.logger = authenticationsdk.logger.Log.setup_logger(self.merchant_config)
        
        self.merchant_config.request_json_path_data =json.dumps(MockData.TRR_DATA)

        self.assertIsNotNone(self.func.get_token(self.merchant_config, self.date, self.logger))

    # This method checks the JWT_Delete token  Generation Unit Testing
    def test_token_for_delete_jwt(self):
        self.merchant_config.set_merchantconfig(MockData.JWT_VALUES)
        self.merchant_config.request_type_method = "DELETE"
        self.merchant_config.request_target = "/reporting/v2/reportSubscriptions/TRRReport?organizationId=testrest/5246387105766473203529"

        self.logger = authenticationsdk.logger.Log.setup_logger(self.merchant_config)

        self.assertIsNotNone(self.func.get_token(self.merchant_config, self.date, self.logger))


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.apis.payer_authentication_api import PayerAuthenticationApi


class TestPayerAuthenticationApi(unittest.TestCase):
    """ PayerAuthenticationApi unit test stubs """

    def setUp(self):
        self.api = CyberSource.apis.payer_authentication_api.PayerAuthenticationApi()

    def tearDown(self):
        pass

    def test_check_payer_auth_enrollment(self):
        """
        Test case for check_payer_auth_enrollment

        Check Payer Auth Enrollment
        """
        pass

    def test_payer_auth_setup(self):
        """
        Test case for payer_auth_setup

        Setup Payer Auth
        """
        pass

    def test_validate_authentication_results(self):
        """
        Test case for validate_authentication_results

        Validate Authentication Results
        """
        pass


if __name__ == '__main__':
    unittest.main()



def get_response_code_message(response):
    switcher = {
        200: "Transaction Successful",
        400: "Bad Request",
        401: "Authentication Failed",
        403: "Forbidden",
        404: "URL Not Found",
        201: "Transaction Successful",
        500: "Internal Server Error",
        502:  "Bad Gateway",
        503: "SERVICE UNAVAILABLE",
        504: "Gateway Timeout"

    }
    return switcher.get(response, "Un-Identified")



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponsePaymentInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'card': 'PtsV2PaymentsPost201ResponsePaymentInformationCard',
        'tokenized_card': 'PtsV2PaymentsPost201ResponsePaymentInformationTokenizedCard',
        'account_features': 'PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures',
        'bank': 'PtsV2PaymentsPost201ResponsePaymentInformationBank',
        'customer': 'Ptsv2paymentsPaymentInformationCustomer',
        'payment_instrument': 'Ptsv2paymentsPaymentInformationPaymentInstrument',
        'instrument_identifier': 'PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier',
        'shipping_address': 'Ptsv2paymentsPaymentInformationShippingAddress',
        'scheme': 'str',
        'bin': 'str',
        'account_type': 'str',
        'issuer': 'str',
        'bin_country': 'str'
    }

    attribute_map = {
        'card': 'card',
        'tokenized_card': 'tokenizedCard',
        'account_features': 'accountFeatures',
        'bank': 'bank',
        'customer': 'customer',
        'payment_instrument': 'paymentInstrument',
        'instrument_identifier': 'instrumentIdentifier',
        'shipping_address': 'shippingAddress',
        'scheme': 'scheme',
        'bin': 'bin',
        'account_type': 'accountType',
        'issuer': 'issuer',
        'bin_country': 'binCountry'
    }

    def __init__(self, card=None, tokenized_card=None, account_features=None, bank=None, customer=None, payment_instrument=None, instrument_identifier=None, shipping_address=None, scheme=None, bin=None, account_type=None, issuer=None, bin_country=None):
        """
        PtsV2PaymentsPost201ResponsePaymentInformation - a model defined in Swagger
        """

        self._card = None
        self._tokenized_card = None
        self._account_features = None
        self._bank = None
        self._customer = None
        self._payment_instrument = None
        self._instrument_identifier = None
        self._shipping_address = None
        self._scheme = None
        self._bin = None
        self._account_type = None
        self._issuer = None
        self._bin_country = None

        if card is not None:
          self.card = card
        if tokenized_card is not None:
          self.tokenized_card = tokenized_card
        if account_features is not None:
          self.account_features = account_features
        if bank is not None:
          self.bank = bank
        if customer is not None:
          self.customer = customer
        if payment_instrument is not None:
          self.payment_instrument = payment_instrument
        if instrument_identifier is not None:
          self.instrument_identifier = instrument_identifier
        if shipping_address is not None:
          self.shipping_address = shipping_address
        if scheme is not None:
          self.scheme = scheme
        if bin is not None:
          self.bin = bin
        if account_type is not None:
          self.account_type = account_type
        if issuer is not None:
          self.issuer = issuer
        if bin_country is not None:
          self.bin_country = bin_country

    @property
    def card(self):
        """
        Gets the card of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :return: The card of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: PtsV2PaymentsPost201ResponsePaymentInformationCard
        """
        return self._card

    @card.setter
    def card(self, card):
        """
        Sets the card of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :param card: The card of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: PtsV2PaymentsPost201ResponsePaymentInformationCard
        """

        self._card = card

    @property
    def tokenized_card(self):
        """
        Gets the tokenized_card of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :return: The tokenized_card of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: PtsV2PaymentsPost201ResponsePaymentInformationTokenizedCard
        """
        return self._tokenized_card

    @tokenized_card.setter
    def tokenized_card(self, tokenized_card):
        """
        Sets the tokenized_card of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :param tokenized_card: The tokenized_card of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: PtsV2PaymentsPost201ResponsePaymentInformationTokenizedCard
        """

        self._tokenized_card = tokenized_card

    @property
    def account_features(self):
        """
        Gets the account_features of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :return: The account_features of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures
        """
        return self._account_features

    @account_features.setter
    def account_features(self, account_features):
        """
        Sets the account_features of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :param account_features: The account_features of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: PtsV2PaymentsPost201ResponsePaymentInformationAccountFeatures
        """

        self._account_features = account_features

    @property
    def bank(self):
        """
        Gets the bank of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :return: The bank of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: PtsV2PaymentsPost201ResponsePaymentInformationBank
        """
        return self._bank

    @bank.setter
    def bank(self, bank):
        """
        Sets the bank of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :param bank: The bank of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: PtsV2PaymentsPost201ResponsePaymentInformationBank
        """

        self._bank = bank

    @property
    def customer(self):
        """
        Gets the customer of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :return: The customer of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: Ptsv2paymentsPaymentInformationCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """
        Sets the customer of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :param customer: The customer of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: Ptsv2paymentsPaymentInformationCustomer
        """

        self._customer = customer

    @property
    def payment_instrument(self):
        """
        Gets the payment_instrument of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :return: The payment_instrument of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: Ptsv2paymentsPaymentInformationPaymentInstrument
        """
        return self._payment_instrument

    @payment_instrument.setter
    def payment_instrument(self, payment_instrument):
        """
        Sets the payment_instrument of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :param payment_instrument: The payment_instrument of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: Ptsv2paymentsPaymentInformationPaymentInstrument
        """

        self._payment_instrument = payment_instrument

    @property
    def instrument_identifier(self):
        """
        Gets the instrument_identifier of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :return: The instrument_identifier of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier
        """
        return self._instrument_identifier

    @instrument_identifier.setter
    def instrument_identifier(self, instrument_identifier):
        """
        Sets the instrument_identifier of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :param instrument_identifier: The instrument_identifier of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: PtsV2PaymentsPost201ResponsePaymentInformationInstrumentIdentifier
        """

        self._instrument_identifier = instrument_identifier

    @property
    def shipping_address(self):
        """
        Gets the shipping_address of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :return: The shipping_address of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: Ptsv2paymentsPaymentInformationShippingAddress
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """
        Sets the shipping_address of this PtsV2PaymentsPost201ResponsePaymentInformation.

        :param shipping_address: The shipping_address of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: Ptsv2paymentsPaymentInformationShippingAddress
        """

        self._shipping_address = shipping_address

    @property
    def scheme(self):
        """
        Gets the scheme of this PtsV2PaymentsPost201ResponsePaymentInformation.
        Subtype of card account. This field can contain one of the following values: - Maestro International - Maestro UK Domestic - MasterCard Credit - MasterCard Debit - Visa Credit - Visa Debit - Visa Electron  **Note** Additional values may be present.  For all possible values, see the `score_card_scheme` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :return: The scheme of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: str
        """
        return self._scheme

    @scheme.setter
    def scheme(self, scheme):
        """
        Sets the scheme of this PtsV2PaymentsPost201ResponsePaymentInformation.
        Subtype of card account. This field can contain one of the following values: - Maestro International - Maestro UK Domestic - MasterCard Credit - MasterCard Debit - Visa Credit - Visa Debit - Visa Electron  **Note** Additional values may be present.  For all possible values, see the `score_card_scheme` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :param scheme: The scheme of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: str
        """
        if scheme is not None and len(scheme) > 255:
            raise ValueError("Invalid value for `scheme`, length must be less than or equal to `255`")

        self._scheme = scheme

    @property
    def bin(self):
        """
        Gets the bin of this PtsV2PaymentsPost201ResponsePaymentInformation.
        Credit card BIN (the first six digits of the credit card).Derived either from the `cc_bin` request field or from the first six characters of the `customer_cc_num` field.  For all possible values, see the `score_cc_bin` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :return: The bin of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: str
        """
        return self._bin

    @bin.setter
    def bin(self, bin):
        """
        Sets the bin of this PtsV2PaymentsPost201ResponsePaymentInformation.
        Credit card BIN (the first six digits of the credit card).Derived either from the `cc_bin` request field or from the first six characters of the `customer_cc_num` field.  For all possible values, see the `score_cc_bin` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :param bin: The bin of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: str
        """
        if bin is not None and len(bin) > 255:
            raise ValueError("Invalid value for `bin`, length must be less than or equal to `255`")

        self._bin = bin

    @property
    def account_type(self):
        """
        Gets the account_type of this PtsV2PaymentsPost201ResponsePaymentInformation.
        Type of payment card account. This field can refer to a credit card, debit card, or prepaid card account type.  For all possible values, see the `score_card_account_type` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :return: The account_type of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: str
        """
        return self._account_type

    @account_type.setter
    def account_type(self, account_type):
        """
        Sets the account_type of this PtsV2PaymentsPost201ResponsePaymentInformation.
        Type of payment card account. This field can refer to a credit card, debit card, or prepaid card account type.  For all possible values, see the `score_card_account_type` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :param account_type: The account_type of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: str
        """
        if account_type is not None and len(account_type) > 255:
            raise ValueError("Invalid value for `account_type`, length must be less than or equal to `255`")

        self._account_type = account_type

    @property
    def issuer(self):
        """
        Gets the issuer of this PtsV2PaymentsPost201ResponsePaymentInformation.
        Name of the bank or entity that issued the card account.  For all possible values, see the `score_card_issuer` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :return: The issuer of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """
        Sets the issuer of this PtsV2PaymentsPost201ResponsePaymentInformation.
        Name of the bank or entity that issued the card account.  For all possible values, see the `score_card_issuer` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :param issuer: The issuer of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: str
        """
        if issuer is not None and len(issuer) > 255:
            raise ValueError("Invalid value for `issuer`, length must be less than or equal to `255`")

        self._issuer = issuer

    @property
    def bin_country(self):
        """
        Gets the bin_country of this PtsV2PaymentsPost201ResponsePaymentInformation.
        Country (two-digit country code) associated with the BIN of the customer’s card used for the payment. Returned if the information is available. Use this field for additional information when reviewing orders. This information is also displayed in the details page of the CyberSource Business Center.  For all possible values, see the `bin_country` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :return: The bin_country of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :rtype: str
        """
        return self._bin_country

    @bin_country.setter
    def bin_country(self, bin_country):
        """
        Sets the bin_country of this PtsV2PaymentsPost201ResponsePaymentInformation.
        Country (two-digit country code) associated with the BIN of the customer’s card used for the payment. Returned if the information is available. Use this field for additional information when reviewing orders. This information is also displayed in the details page of the CyberSource Business Center.  For all possible values, see the `bin_country` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :param bin_country: The bin_country of this PtsV2PaymentsPost201ResponsePaymentInformation.
        :type: str
        """
        if bin_country is not None and len(bin_country) > 255:
            raise ValueError("Invalid value for `bin_country`, length must be less than or equal to `255`")

        self._bin_country = bin_country

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponsePaymentInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import CyberSource
from CyberSource.rest import ApiException
from CyberSource.apis.void_api import VoidApi


class TestVoidApi(unittest.TestCase):
    """ VoidApi unit test stubs """

    def setUp(self):
        self.api = CyberSource.apis.void_api.VoidApi()

    def tearDown(self):
        pass

    def test_mit_void(self):
        """
        Test case for mit_void

        Timeout Void
        """
        pass

    def test_void_capture(self):
        """
        Test case for void_capture

        Void a Capture
        """
        pass

    def test_void_credit(self):
        """
        Test case for void_credit

        Void a Credit
        """
        pass

    def test_void_payment(self):
        """
        Test case for void_payment

        Void a Payment
        """
        pass

    def test_void_refund(self):
        """
        Test case for void_refund

        Void a Refund
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseRiskInformationProfile(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'desination_queue': 'str',
        'selector_rule': 'str'
    }

    attribute_map = {
        'name': 'name',
        'desination_queue': 'desinationQueue',
        'selector_rule': 'selectorRule'
    }

    def __init__(self, name=None, desination_queue=None, selector_rule=None):
        """
        PtsV2PaymentsPost201ResponseRiskInformationProfile - a model defined in Swagger
        """

        self._name = None
        self._desination_queue = None
        self._selector_rule = None

        if name is not None:
          self.name = name
        if desination_queue is not None:
          self.desination_queue = desination_queue
        if selector_rule is not None:
          self.selector_rule = selector_rule

    @property
    def name(self):
        """
        Gets the name of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        Name of the active profile chosen by the profile selector. If no profile selector exists, the default active profile is chosen.  **Note** By default, your default profile is the active profile, or the Profile Selector chooses the active profile. Use this field only if you want to specify the name of a different profile. The passed-in profile will then become the active profile. 

        :return: The name of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        Name of the active profile chosen by the profile selector. If no profile selector exists, the default active profile is chosen.  **Note** By default, your default profile is the active profile, or the Profile Selector chooses the active profile. Use this field only if you want to specify the name of a different profile. The passed-in profile will then become the active profile. 

        :param name: The name of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        :type: str
        """
        if name is not None and len(name) > 30:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `30`")

        self._name = name

    @property
    def desination_queue(self):
        """
        Gets the desination_queue of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        Name of the queue where orders that are not automatically accepted are sent. 

        :return: The desination_queue of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        :rtype: str
        """
        return self._desination_queue

    @desination_queue.setter
    def desination_queue(self, desination_queue):
        """
        Sets the desination_queue of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        Name of the queue where orders that are not automatically accepted are sent. 

        :param desination_queue: The desination_queue of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        :type: str
        """
        if desination_queue is not None and len(desination_queue) > 255:
            raise ValueError("Invalid value for `desination_queue`, length must be less than or equal to `255`")

        self._desination_queue = desination_queue

    @property
    def selector_rule(self):
        """
        Gets the selector_rule of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        Name of the profile selector rule that chooses the profile to use for the transaction. If no profile selector exists, the value is Default Active Profile. 

        :return: The selector_rule of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        :rtype: str
        """
        return self._selector_rule

    @selector_rule.setter
    def selector_rule(self, selector_rule):
        """
        Sets the selector_rule of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        Name of the profile selector rule that chooses the profile to use for the transaction. If no profile selector exists, the value is Default Active Profile. 

        :param selector_rule: The selector_rule of this PtsV2PaymentsPost201ResponseRiskInformationProfile.
        :type: str
        """
        if selector_rule is not None and len(selector_rule) > 255:
            raise ValueError("Invalid value for `selector_rule`, length must be less than or equal to `255`")

        self._selector_rule = selector_rule

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseRiskInformationProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



import os
class GlobalLabelParameters:
    POST = "POST"
    GET = "GET"
    PUT = "PUT"
    DELETE = "DELETE"
    PATCH = "PATCH"
    GET_LOWER_CASE = "get "
    POST_LOWER_CASE = "post "
    PUT_LOWER_CASE = "put "
    DELETE_LOWER_CASE = "delete "
    PATCH_LOWER_CASE = "patch "
    HTTP_URL_PREFIX = "https://"
    HTTP = "HTTP_Signature"
    MERCHANT_ID = "v-c-merchant-id"
    AUTHORIZATION_BEARER = "Authorization"
    REQUEST_TARGET = "(request-target)"
    PUBLIC_KEY = "x5c"
    JWT = "JWT"
    DATE = "Date"
    HOST = "Host"
    SIGNATURE = "Signature"
    USER_AGENT = "User-Agent"
    USER_AGENT_VALUE = "Mozilla/5.0"
    CONTENT_TYPE = "Content-Type"
    APPLICATION_JSON = "application/json"
    V_C_CORRELATION_ID = "v-c-correlation-id"
    DIGEST = "Digest"
    REQUEST_TYPE = "Request Type"
    URL = "URL"
    DIGEST_PREFIX = "SHA-256="
    P12_PREFIX = ".p12"
    SIGNATURE_HEADER = ", signature=\""
    ALGORITHM = ", algorithm=\"HmacSHA256\""
    HEADERS_PARAM = ", headers=\""
    MASKING_VALUE = "XXXXX"
    JWT_TIME = "iat"
    JWT_ALGORITHM = "digestAlgorithm"
    JWT_DIGEST = "digest"
    CYBS_FILE_NAME = 'config_params'
    KEY_ID = "keyid=\""
    LOG_FILE_NAME_DEFAULT = "cybs"
    SANBOX_URL = "apitest.cybersource.com"
    PRODUCTION_URL = "api.cybersource.com"
    SANBOX_RUN_ENVIRONMENT = "CyberSource.Environment.SANDBOX"
    PRODUCTION_RUN_ENVIRONMENT = "CyberSource.Environment.PRODUCTION"
    BOA_SANDBOX_URL = "apitest.merchant-services.bankofamerica.com"
    BOA_PRODUCTION_URL = "api.merchant-services.bankofamerica.com"
    BOA_SANDBOX_RUN_ENVIRONMENT = "BankofAmerica.Environment.SANDBOX"
    BOA_PRODUCTION_RUN_ENVIRONMENT = "BankofAmerica.Environment.PRODUCTION"
    IDC_SANDBOX_URL = "apitest.cybersource.com"
    IDC_PRODUCTION_URL = "api.in.cybersource.com"
    IDC_SANDBOX_RUN_ENVIRONMENT = "CyberSource.in.Environment.SANDBOX"
    IDC_PRODUCTION_RUN_ENVIRONMENT = "CyberSource.in.Environment.PRODUCTION"
    HIDE_MERCHANT_CONFIG_PROPS = "merchantid,merchant_secretkey,merchant_keyid,key_alias,key_password"
    PROXY_PREFIX = "https"
    FILE_NOT_FOUND = "File not found. Check path/filename entered. Entered path/filename : "
    SYSTEM_ERROR = "System error encountered while accessing file : "
    AUTH_ERROR = "Check Authentication Type (HTTP_Signature/JWT) in cybs.json."
    KEY_ALIAS_NULL_EMPTY = "KeyAlias Empty/None. Assigining merchantID value"
    INVALID_KEY_ALIAS = "KeyAlias Invalid. Assigining merchantID value"
    REQUEST_JSON_ERROR = "Request Json File missing. File Path :: "
    KEY_FILE_EMPTY = "KeyFileName is empty, Assigining merchantID value"
    REFER_LOG = "Please refer Log for details"
    MERCHANTID_REQ = "MerchantID is mandatory"
    NOT_ENTERED = "The Following Parameter is Missing in Cybs.Json::"
    INCORRECT_KEY_PASSWORD = "The Entered key_password is Incorrect"
    AUTHENTICATION_REQ = "AuthenticationType is Mandatory"
    MERCHANT_KEY_ID_REQ = "MerchantKeyId is Mandatory"
    MERCHANT_SECRET_KEY_REQ = " MerchantSecretKey is Mandatory"
    KEY_PASSWORD_EMPTY = "KeyPassword Empty/None. Assigining merchantID value"
    INVALID_KEY_PASSWORD = "KeyPassword Invalid. Assigining merchantID value"
    KEY_DIRECTORY_EMPTY = "KeysDirectory not provided. Using Default Path:"
    REQUEST_JSON_EMPTY = "RequestJsonPath not provided"
    INVALID_REQUEST_TYPE_METHOD = "Entered Request Type should be (GET/POST/PUT/PATCH)"
    RUN_ENVIRONMENT_EMPTY = "RunEnvironment Is Mandatory."
    DEFAULT_LOG_FILE_NAME = "Log File Name Empty/None.Using Default Value"
    DEFAULT_ENABLE_LOG = True
    DEFAULT_MAXIMUM_SIZE = 10487560
    DEFAULT_TIMEOUT = 1000
    DEFAULT_LOG_DIRECTORY =os.path.join(os.getcwd(),"Logs")
    DEFAULT_PROXY_ADDRESS = "userproxy.visa.com"
    DEFAULT_PROXY_PORT = 443
    DEFAULT_KEY_FILE_PATH = os.path.join(os.getcwd(),"resources")
    ENABLE_LOG_DEFAULT_MESSAGE = "Enable log value Empty/None.Using Default Value"
    LOG_MAXIMUM_SIZE_DEFAULT_MESSAGE = "Log Maximum Size Empty/None.Using Default Value"
    LOG_DIRECTORY_DEFAULT_MESSAGE = "Log Directory value Empty/None.Using Default Value"
    LOG_DIRECTORY_INCORRECT_MESSAGE = "Log Directory value Incorrect.Using Default Value"
    INVALID_CYBS_PATH = "The Cybs.Json Path Provided Is Incorrect"
